import { createSlice, } from '@reduxjs/toolkit';
import { all, take, takeEvery, takeLatest, takeLeading, takeMaybe, } from 'redux-saga/effects';
function getSpawnType(spawnType) {
    switch (spawnType) {
        case 'take':
            return take;
        case 'takeEvery':
            return takeEvery;
        case 'takeLatest':
            return takeLatest;
        case 'takeLeading':
            return takeLeading;
        case 'takeMaybe':
            return takeMaybe;
        default:
            return 'takeEvery';
    }
}
export function createSaga(options) {
    const { name, initialState, reducers, extraReducers, sagas } = options;
    const newSlice = createSlice({
        name: name,
        initialState: initialState,
        reducers: reducers,
        extraReducers: extraReducers,
    });
    const result = {
        actions: newSlice.actions,
        reducer: newSlice.reducer,
        saga: undefined,
    };
    if (sagas && Object.keys(sagas).length > 0) {
        const _saga = function* createNewSaga() {
            yield all(Object.keys(sagas)
                .map((sagaName) => getSpawnType(sagas?.[sagaName]?.spawnType)?.(result.actions?.[sagaName], sagas?.[sagaName]?.action))
                .filter((saga) => !!saga));
        };
        result.saga = _saga;
    }
    return result;
}
