import { createSlice } from '@reduxjs/toolkit';
import { AppState } from 'react-native';
const initialState = {
    isConnected: true,
    appState: AppState.isAvailable ? AppState.currentState : null,
};
class ConnectRepository {
    static sliceName = 'connect';
    static _instance;
    static instance(initial) {
        if (!ConnectRepository._instance) {
            ConnectRepository._instance = new ConnectRepository(initial);
        }
        return ConnectRepository._instance;
    }
    _slices;
    constructor(initial) {
        if (!initial) {
            this.initialize();
        }
        else {
            this._slices = initial();
        }
    }
    initialize() {
        this._slices = createSlice({
            name: ConnectRepository.sliceName,
            initialState,
            reducers: {
                setConnected: (state, action) => {
                    return {
                        ...state,
                        isConnected: action?.payload,
                    };
                },
                setAppState: (state, action) => {
                    return {
                        ...state,
                        appState: action?.payload,
                    };
                },
            },
        });
    }
    get reducer() {
        return this._slices.reducer;
    }
    get actions() {
        return this._slices.actions;
    }
    get slice() {
        return this._slices;
    }
}
const connectRepo = ConnectRepository.instance();
export { ConnectRepository, connectRepo };
